@@ -328,9 +328,9 @@ path_in_path (const char *dirname,
 goffset
 get_file_size (const char *uri)
 {
+	goffset    size = 0;
 	GFile     *file;
 	GFileInfo *info;
-	goffset    size;
 	GError    *err = NULL;
 
 	if ((uri == NULL) || (*uri == '\0'))
@@ -907,7 +907,7 @@ ith_temp_folder_to_try (int n)
 
 
 char *
-get_temp_work_dir (void)
+get_temp_work_dir (const char *parent_folder)
 {
 	guint64  max_size = 0;
 	char    *best_folder = NULL;
@@ -915,23 +915,27 @@ get_temp_work_dir (void)
 	char    *template;
 	char    *result = NULL;
 
-	/* find the folder with more free space. */
-
-	for (i = 0; try_folder[i] != NULL; i++) {
-		char    *folder;
-		guint64  size;
-
-		folder = ith_temp_folder_to_try (i);
-		size = get_dest_free_space (folder);
-		if (max_size < size) {
-			max_size = size;
-			g_free (best_folder);
-			best_folder = folder;
+	if (parent_folder == NULL) { 	
+		/* find the folder with more free space. */
+	
+		for (i = 0; try_folder[i] != NULL; i++) {
+			char    *folder;
+			guint64  size;
+	
+			folder = ith_temp_folder_to_try (i);
+			size = get_dest_free_space (folder);
+			if (max_size < size) {
+				max_size = size;
+				g_free (best_folder);
+				best_folder = folder;
+			}
+			else
+				g_free (folder);
 		}
-		else
-			g_free (folder);
-	}
-
+	}	
+	else 
+		best_folder = g_strdup (parent_folder);
+		
 	if (best_folder == NULL)
 		return NULL;
 	
@@ -951,6 +955,7 @@ gboolean
 is_temp_work_dir (const char *dir)
 {
 	int i;
+	const char *folder;
 
 	if (strncmp (dir, "file://", 7) == 0)
 		dir = dir + 7;
@@ -958,14 +963,16 @@ is_temp_work_dir (const char *dir)
 		return FALSE;
 
 	for (i = 0; try_folder[i] != NULL; i++) {
-		const char *folder;
 
 		folder = ith_temp_folder_to_try (i);
 		if (strncmp (dir, folder, strlen (folder)) == 0)
-			if (strncmp (dir + strlen (folder), "/.fr-", 5) == 0)
+			if (strncmp (dir + strlen (folder), "/.fr-", 5) == 0) {
+				g_free (folder);
 				return TRUE;
+			}
 	}
 
+	g_free (folder);
 	return FALSE;
 }
 
@@ -1103,17 +1110,30 @@ file_list__get_prev_field (const char *line,
 gboolean
 check_permissions (const char *uri,
 		   int         mode)
+{
+	GFile    *file;
+	gboolean  result;
+
+	file = g_file_new_for_uri (uri);
+	result = check_file_permissions (file, mode);
+
+	g_object_unref (file);
+
+	return result;
+}
+
+
+gboolean
+check_file_permissions (GFile *file,
+		        int    mode)
 {
 	gboolean   result = TRUE;
-	GFile     *file;
 	GFileInfo *info;
 	GError    *err = NULL;
 	gboolean   default_permission_when_unknown = TRUE;
 
-	file = g_file_new_for_uri (uri);
 	info = g_file_query_info (file, "access::*", 0, NULL, &err);
 	if (err != NULL) {
-		g_warning ("Failed to get access permissions: %s", err->message);
 		g_clear_error (&err);
 		result = FALSE;
 	}
@@ -1124,24 +1144,23 @@ check_permissions (const char *uri,
 			else
 				result = (result && default_permission_when_unknown);
 		}
-		
+
 		if ((mode & W_OK) == W_OK) {
 			if (g_file_info_has_attribute (info, G_FILE_ATTRIBUTE_ACCESS_CAN_WRITE))
 				result = (result && g_file_info_get_attribute_boolean (info, G_FILE_ATTRIBUTE_ACCESS_CAN_WRITE));
 			else
 				result = (result && default_permission_when_unknown);
 		}
-		
+
 		if ((mode & X_OK) == X_OK) {
 			if (g_file_info_has_attribute (info, G_FILE_ATTRIBUTE_ACCESS_CAN_EXECUTE))
 				result = (result && g_file_info_get_attribute_boolean (info, G_FILE_ATTRIBUTE_ACCESS_CAN_EXECUTE));
 			else
 				result = (result && default_permission_when_unknown);
 		}
-	}		
-	
-	g_object_unref (info);
-	g_object_unref (file);
+
+		g_object_unref (info);
+	}
 
 	return result;
 }
@@ -1174,6 +1193,14 @@ is_program_in_path (const char *filename)
 }
 
 
+gboolean
+is_program_available (const char *filename,
+		      gboolean    check)
+{
+	return ! check || is_program_in_path (filename);
+}
+
+
 const char *
 get_home_uri (void)
 {
